SeqBindError

Enum SeqBindError 

#[non_exhaustive]
pub enum SeqBindError { Empty, PrefixShadow { sequence: Vec<KeyInput>, conflict: Vec<KeyInput>, }, }
Why a SequenceKeymap::bind call was rejected.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Empty

The sequence contained no keys.



PrefixShadow

The sequence collides with an existing binding on a shared prefix: one is a proper prefix of the other, which cannot be resolved without a timeout.

Fields

sequence: Vec<KeyInput>

The sequence whose binding was rejected.

conflict: Vec<KeyInput>

An existing binding it collides with — one of sequence/conflict is a proper prefix of the other. When several existing bindings share the prefix, this names one of them.